FillBetweenItem — pyqtgraph 0.11.0rc0 documentation

# FillBetweenItem

class `pyqtgraph.` `FillBetweenItem`(curve1=None, curve2=None, brush=None, pen=None)

  GraphicsItem filling the space between two PlotDataItems.

  `__init__`(curve1=None, curve2=None, brush=None, pen=None)

    Initialize self. See help(type(self)) for accurate signature.

  `setBrush`(*args, **kwds)

    Change the fill brush. Acceps the same arguments as pg.mkBrush()

  `setCurves`(curve1, curve2)

    Set the curves to fill between.

    Arguments must be instances of PlotDataItem or PlotCurveItem.

    Added in version 0.9.9

  `setPen`(self, pen: PySide2.QtGui.QPen)